@@ -49,7 +49,7 @@ class CreateSessionRequest(AbstractModel):
         :type MinBitrate: int
         :param Fps: 帧率，可设置为30、45、60、90、120、144
         :type Fps: int
-        :param UserIp: 【已废弃】只在TrylockWorker时生效
+        :param UserIp: 【必选】用户IP，用户客户端的公网IP，用于就近调度，不填将严重影响用户体验
         :type UserIp: str
         :param Optimization: 【已废弃】优化项，便于客户灰度开启新的优化项，默认为0
         :type Optimization: int
@@ -442,7 +442,7 @@ class TrylockWorkerRequest(AbstractModel):
         :type GameRegion: str
         :param SetNo: 【废弃】资源池编号
         :type SetNo: int
-        :param UserIp: 【必选】用户IP，用于就近调度，不填将严重影响用户体验
+        :param UserIp: 【必选】用户IP，用户客户端的公网IP，用于就近调度，不填将严重影响用户体验
         :type UserIp: str
         :param GroupId: 分组ID
         :type GroupId: str
